@@ -2,7 +2,7 @@ package Lingua::EN::Inflexion;
 use 5.010; use warnings;
 use Carp;
 
-our $VERSION = '0.002004';
+our $VERSION = '0.002005';
 
 # Import noun, verb, and adj classes...
 use Lingua::EN::Inflexion::Term;
@@ -213,7 +213,7 @@ Lingua::EN::Inflexion - Inflect English nouns, verbs, adjectives, and articles
 
 =head1 VERSION
 
-This document describes Lingua::EN::Inflexion version 0.002004
+This document describes Lingua::EN::Inflexion version 0.002005
 
 
 =head1 SYNOPSIS
@@ -396,6 +396,23 @@ singular forms, the method always prefers the gender neutral form:
     say adj("our")->singular(3);    # "its" (not "hers" or "his")
 
 
+Note that these methods all all attempt to preserve the original
+typographical casing of the initial word:
+
+    say noun("dog")->plural;        # "dogs"
+    say noun("Dog")->plural;        # "Dogs"
+    say noun("DOG")->plural;        # "DOGS"
+
+    say verb("sits")->plural;       # "sit"
+    say verb("Sits")->plural;       # "Sit"
+    say verb("SITS")->plural;       # "SIT"
+
+This can occasionally lead to anomalous (or unintentionally humorous) results:
+
+    "I got a B on my test"  --> "We got some BS on our tests"
+
+
+
 =item  C<< classical() >> or C<< unassimilated() >>
 
 This is a single method with two alternative names. It returns an
